@@ -10,15 +10,16 @@ def load():
     config['DEFAULT'] = {}
 
     config['UI'] = {
-            'max_result_count': "10",
+            'max_result_count': "20",
     }
 
     config['DL_OPTIONS'] = {
             'fmt': "native",
             'lyrics': "False",
             'bitrate': '250',
-            'default_directory': "./",
-            'multiple': '1',
+            'default_directory': os.path.expanduser("~/Music/$artist/$album/"),
+            'filename': "$artist-$name-$year",
+            'multiple': '4',
     }
 
     config['API_KEYS'] = {
@@ -28,10 +29,14 @@ def load():
     }
 
     config['STREAM'] = {
-            'player_cmd': ["mpv",  "$audio", "--cover-art-file=$cover",
-                "--osd-msg2=$title", '--osd-level=2', '--really-quiet'],
+            'player_cmd': ['setsid', '-f', 'mpv', '$audio',
+                '--cover-art-file=$cover',
+                '--force-media-title=$title',
+                '--really-quiet',
+                '--oset-metadata-set=comment="a"', '--no-terminal'],
     }
 
+
     file_path = os.getenv('FMDPY_CONFIG_FILE') or \
         os.path.expanduser('~/.fmdpy.ini')
 
